@@ -7,7 +7,7 @@ from .functions_tex import files as file_list
 tikz_render=r"""
 \vspace*{\fill}
 \begin{center}
-\input{tikz.tex}
+    \input{tikz.tex}
 \end{center}
 \vspace*{\fill}
 \pagebreak
@@ -19,6 +19,15 @@ tikz_code=r"""
 \vspace*{\fill}
 """
 
+qrcode=r""""
+\vspace*{\fill}
+\begin{center}
+    \fbox{\qrcode[height=2cm]{\gdrive}}
+\end{center}
+\vspace*{\fill}
+"""
+
+
 
 @click.command(
         help="Extracts tex environments from tex files"
@@ -66,7 +75,7 @@ def main(inputfile, outputfile, environment):
         file.write(f'\\vgeometry\n')
 
         file.write(f'\\begin{{document}}\n')
-
+        file.write(f'\\def\\gdrive{{Link}}\n\n')
         print(files)
         if len(files) == 1:
             file.write(f'{tikz_render.replace("tikz.tex", files[0])}\n')
@@ -75,9 +84,10 @@ def main(inputfile, outputfile, environment):
             for f in files[1:]:
                 file.write(f'{tikz_render.replace("tikz.tex", f)}\n')
                 file.write(f'{tikz_code.replace("tikz.tex", f)}\n')
-                if f != files[-1]:
-                    file.write(f'\\pagebreak\n')
+                file.write(f'\\pagebreak\n')
 
+
+        file.write(f'{qrcode}\n')
         file.write(f'\\end{{document}}')
 
 
